/*
 * ******************************************************************************************
 *
 * File		: apb_wdt_driver.h
 * Author	: GOWIN
 * Function	: Driver definition of APB Watchdog
 *
 * ******************************************************************************************
 */

#ifndef __APB_WDT_DRIVER_H__
#define __APB_WDT_DRIVER_H__


#ifdef __cplusplus
extern "C" {
#endif


// Includes ---------------------------------------------------------------------------------
#include "apb_wdt.h"


// Definitions ------------------------------------------------------------------------------

/*****************************************************************************
  \fn          APB_WDT_CAPABILITIES apb_wdt_get_capabilities (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Get driver capabilities
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      APB_WDT_CAPABILITIES
******************************************************************************/
APB_WDT_CAPABILITIES apb_wdt_get_capabilities(APB_WDT_RESOURCES *apb_wdtx);

/*****************************************************************************
  \fn          int apb_wdt_initialize (APB_WDT_SignalEvent_t cb_event, APB_WDT_RESOURCES *apb_wdtx)
  \brief       Initialize APB WDT Interface.
  \param[in]   cb_event  Pointer to APB_WDT_SignalEvent
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      execution_status
******************************************************************************/
int apb_wdt_initialize(APB_WDT_SignalEvent_t cb_event, APB_WDT_RESOURCES *apb_wdtx);

/*****************************************************************************
  \fn          int apb_wdt_uninitialize (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Uninitialized APB WDT Interface.
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      execution_status
******************************************************************************/
int apb_wdt_uninitialize(APB_WDT_RESOURCES *apb_wdtx);

/*****************************************************************************
  \fn          void apb_wdt_restart_timer (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Restart APB WDT Timer
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      none
******************************************************************************/
void apb_wdt_restart_timer(APB_WDT_RESOURCES *apb_wdtx);

/******************************************************************************
  \fn          void apb_wdt_clear_irq_status (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Clear APB WDT IRQ Expired status
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      none
*******************************************************************************/
void apb_wdt_clear_irq_status(APB_WDT_RESOURCES *apb_wdtx);

/******************************************************************************
  \fn          int apb_wdt_control (unsigned int control, unsigned int arg, APB_WDT_RESOURCES *apb_wdtx)
  \brief       Control APB WDT Interface.
  \param[in]   control  Operation
  \param[in]   arg      Argument of operation (optional)
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      common   execution_status and driver specific
  	  	  	  	  	    apb_wdt_execution_status
*******************************************************************************/
int apb_wdt_control(unsigned int control, unsigned int arg, APB_WDT_RESOURCES *apb_wdtx);

/******************************************************************************
  \fn          void apb_wdt_enable (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Enable APB WDT Timer
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      none
*******************************************************************************/
void apb_wdt_enable(APB_WDT_RESOURCES *apb_wdtx);

/******************************************************************************
  \fn          void apb_wdt_disable (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Disable APB WDT Timer
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      none
*******************************************************************************/
void apb_wdt_disable(APB_WDT_RESOURCES *apb_wdtx);

/*******************************************************************************
  \fn          APB_WDT_STATUS apb_wdt_get_status (APB_WDT_RESOURCES *apb_wdtx)
  \brief       Get APB WDT status.
  \param[in]   apb_wdtx Pointer to APB WDT resources
  \return      APB WDT status APB_WDT_STATUS
********************************************************************************/
APB_WDT_STATUS apb_wdt_get_status(APB_WDT_RESOURCES *apb_wdtx);


#ifdef __cplusplus
}
#endif


#endif	/* __APB_WDT_DRIVER_H__ */
