/*
 * ******************************************************************************************
 *
 * File		: apb_wdt_dev.h
 * Author	: GOWIN
 * Function	: Device definition of APB Watchdog1
 *
 * ******************************************************************************************
 */

#ifndef __APB_WDT_DEV_H__
#define __APB_WDT_DEV_H__


#ifdef __cplusplus
extern "C" {
#endif


// Includes ---------------------------------------------------------------------------------
#include "apb_wdt.h"
#include "platform.h"


// Definitions ------------------------------------------------------------------------------

/*************************************************************************************
 * An APB Watchdog device "APB WDT1" is defined as a user template.
 * User can define more APB Watchdog devices.
 *************************************************************************************/

/*************************************************************************************
 * "X" represents user customized.
 *************************************************************************************/

#define APB_WDT1_BASE					APB_EXT_BASE/*X*/						// APB WDT1 address definition
#define APB_WDT1						((APB_WDT_RegDef *) APB_WDT1_BASE )		// APB WDT1 register definition

#define IRQ_APB_WDT1_SOURCE				IRQ_GP0_SOURCE/*X*/						// APB WDT1 interrupt source
#define apb_wdt1_irq_handler			gp0_irq_handler/*X*/					// APB WDT1 interrupt handler


// APB WDT1 info
static APB_WDT_INFO apb_wdt1_info = {0};

// APB WDT1 resources
static const APB_WDT_RESOURCES apb_wdt1_resources =
{
	{
	1,
	1,
	},
	APB_WDT1,
	&apb_wdt1_info
};


/*************************************************************************************
 * Functions
 *************************************************************************************/

/*****************************************************************************
  \fn          APB_WDT_CAPABILITIES apb_wdt1_get_capabilities (void)
  \brief       Get driver capabilities
  \return      APB_WDT_CAPABILITIES
******************************************************************************/
APB_WDT_CAPABILITIES apb_wdt1_get_capabilities(void);

/*****************************************************************************
  \fn          int apb_wdt1_initialize (APB_WDT_SignalEvent_t cb_event)
  \brief       Initialize APB WDT Interface.
  \param[in]   cb_event  Pointer to APB_WDT_SignalEvent
  \return      execution_status
******************************************************************************/
int apb_wdt1_initialize(APB_WDT_SignalEvent_t cb_event);

/*****************************************************************************
  \fn          int apb_wdt1_uninitialize (void)
  \brief       Uninitialized APB WDT Interface.
  \return      execution_status
******************************************************************************/
int apb_wdt1_uninitialize(void);

/*****************************************************************************
  \fn          void apb_wdt1_restart_timer (void)
  \brief       Restart APB WDT Timer
  \return      none
******************************************************************************/
void apb_wdt1_restart_timer(void);

/******************************************************************************
  \fn          void apb_wdt1_clear_irq_status (void)
  \brief       Clear APB WDT IRQ Expired status
  \return      none
*******************************************************************************/
void apb_wdt1_clear_irq_status(void);

/******************************************************************************
  \fn          int apb_wdt1_control (unsigned int control, unsigned int arg)
  \brief       Control APB WDT Interface.
  \param[in]   control  Operation
  \param[in]   arg      Argument of operation (optional)
  \return      common   execution_status and driver specific
  	  	  	  	  	    apb_wdt_execution_status
*******************************************************************************/
int apb_wdt1_control(unsigned int control, unsigned int arg);

/******************************************************************************
  \fn          void apb_wdt1_enable (void)
  \brief       Enable APB WDT Timer
  \return      none
*******************************************************************************/
void apb_wdt1_enable(void);

/******************************************************************************
  \fn          void apb_wdt1_disable (void)
  \brief       Disable APB WDT Timer
  \return      none
*******************************************************************************/
void apb_wdt1_disable(void);

/*******************************************************************************
  \fn          APB_WDT_STATUS apb_wdt1_get_status (void)
  \brief       Get APB WDT status.
  \return      APB WDT status APB_WDT_STATUS
********************************************************************************/
APB_WDT_STATUS apb_wdt1_get_status(void);


// As this template, user can define more APB Watchdog devices.


#ifdef __cplusplus
}
#endif


#endif	/* __APB_WDT_DEV_H__ */
