/*
 * ******************************************************************************************
 *
 * File		: apb_wdt_dev.c
 * Author	: GOWIN
 * Function	: Device definition of APB Watchdog1
 *
 * ******************************************************************************************
 */

// Includes ---------------------------------------------------------------------------------
#include "apb_wdt_dev.h"
#include "apb_wdt_driver.h"


// Definitions ------------------------------------------------------------------------------

/*****************************************************************************
  \fn          APB_WDT_CAPABILITIES apb_wdt1_get_capabilities (void)
  \brief       Get driver capabilities
  \return      APB_WDT_CAPABILITIES
******************************************************************************/
APB_WDT_CAPABILITIES apb_wdt1_get_capabilities(void)
{
	return apb_wdt_get_capabilities(&apb_wdt1_resources);
}

/*****************************************************************************
  \fn          int apb_wdt1_initialize (APB_WDT_SignalEvent_t cb_event)
  \brief       Initialize APB WDT Interface.
  \param[in]   cb_event  Pointer to APB_WDT_SignalEvent
  \return      execution_status
******************************************************************************/
int apb_wdt1_initialize(APB_WDT_SignalEvent_t cb_event)
{
	return apb_wdt_initialize(cb_event, &apb_wdt1_resources);
}

/*****************************************************************************
  \fn          int apb_wdt1_uninitialize (void)
  \brief       Uninitialized APB WDT Interface.
  \return      execution_status
******************************************************************************/
int apb_wdt1_uninitialize(void)
{
	return apb_wdt_uninitialize(&apb_wdt1_resources);
}

/*****************************************************************************
  \fn          void apb_wdt1_restart_timer (void)
  \brief       Restart APB WDT Timer
  \return      none
******************************************************************************/
void apb_wdt1_restart_timer(void)
{
	apb_wdt_restart_timer(&apb_wdt1_resources);
}

/******************************************************************************
  \fn          void apb_wdt1_clear_irq_status (void)
  \brief       Clear APB WDT IRQ Expired status
  \return      none
*******************************************************************************/
void apb_wdt1_clear_irq_status(void)
{
	apb_wdt_clear_irq_status(&apb_wdt1_resources);
}

/******************************************************************************
  \fn          int apb_wdt1_control (unsigned int control, unsigned int arg)
  \brief       Control APB WDT Interface.
  \param[in]   control  Operation
  \param[in]   arg      Argument of operation (optional)
  \return      common   execution_status and driver specific
  	  	  	  	  	    apb_wdt_execution_status
*******************************************************************************/
int apb_wdt1_control(unsigned int control, unsigned int arg)
{
	return apb_wdt_control(control, arg, &apb_wdt1_resources);
}

/******************************************************************************
  \fn          void apb_wdt1_enable (void)
  \brief       Enable APB WDT Timer
  \return      none
*******************************************************************************/
void apb_wdt1_enable(void)
{
	apb_wdt_enable(&apb_wdt1_resources);
}

/******************************************************************************
  \fn          void apb_wdt1_disable (void)
  \brief       Disable APB WDT Timer
  \return      none
*******************************************************************************/
void apb_wdt1_disable(void)
{
	apb_wdt_disable(&apb_wdt1_resources);
}

/*******************************************************************************
  \fn          APB_WDT_STATUS apb_wdt1_get_status (void)
  \brief       Get APB WDT status.
  \return      APB WDT status APB_WDT_STATUS
********************************************************************************/
APB_WDT_STATUS apb_wdt1_get_status(void)
{
	return apb_wdt_get_status(&apb_wdt1_resources);
}


/* NMI interrupt handler */
void nmi_handler(void)
{
	APB_WDT_STATUS status = apb_wdt_get_status(&apb_wdt1_resources);

	if( status.irq_expired )
	{
		apb_wdt1_resources.info->cb_event(0);
	}

	// Wait APB WDT reset signal to reset system.
	while(1);
}
