/*
 * ******************************************************************************************
 *
 * File		: main.c
 * Author	: GOWIN
 * Function	: APB Watchdog demo
 *
 * ******************************************************************************************
 */

// Includes ---------------------------------------------------------------------------------
#include "apb_wdt_dev.h"
#include "uart.h"
#include <stdio.h>


// Definitions ------------------------------------------------------------------------------

/* Interrupt handlers */
void apb_wdt1_irq_handler (unsigned int event)
{
    printf("APB WDT activated\r\n");
}

/* Application entry function */
int main(void)
{
	APB_WDT_CAPABILITIES drv_capabilities;

    drv_capabilities = apb_wdt1_get_capabilities();

    // Initializes UART2
    uart_init(38400);	// Baud rate is 38400

    printf("\r\nIt's a APB Watchdog demo.\r\n");

    // Disable Machine External interrupt
    HAL_MEIP_DISABLE();

    // Initializes APB WDT
    if (drv_capabilities.irq_stage)
    {
    	apb_wdt1_initialize(apb_wdt1_irq_handler);
    }
    else
    {
    	apb_wdt1_initialize(NULL);
    }

    // Set APB WDT source clock
    if (drv_capabilities.external_timer)
    {
        /* Under external clock rate, pow(2, 15) ticks are 1 second. */
    	apb_wdt1_control(APB_WDT_CLKSRC_EXTERNAL, APB_WDT_TIME_POW_2_15);
    }
    else
    {
        /* Under APB clock rate, pow(2, 15) ticks are nearly 1.5 microseconds. */
    	apb_wdt1_control(APB_WDT_CLKSRC_APB, APB_WDT_TIME_POW_2_15);
    }

    // Enable interrupt
    HAL_INTERRUPT_SET_LEVEL(IRQ_APB_WDT1_SOURCE, 1);
    HAL_INTERRUPT_ENABLE(IRQ_APB_WDT1_SOURCE);
	HAL_MEIP_ENABLE();
	HAL_MIE_ENABLE();

	// Enable WDT
	apb_wdt1_enable();

    // Start watch dog timer
	apb_wdt1_restart_timer();

    while (1)
    {
    	printf("loop\r\n");
    }

    return 0;
}
